@@ -19,10 +19,8 @@
 
 #include "../dialog/showarchivestructuredialog.h"
 
-#include <KLocalizedString>
 #include <QFileDialog>
 #include <QApplication>
-#include <KAboutData>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
 #include <QStandardPaths>
@@ -31,22 +29,17 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData aboutData(QStringLiteral("showarchivestructuredialog_gui"), i18n("showarchivestructuredialog_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for showarchivestructuredialog"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"), i18n("URL of a archive to open")));
-    aboutData.setupCommandLine(&parser);
+    parser.addOption(QCommandLineOption(QStringList() << QStringLiteral("+[url]"), QStringLiteral("URL of a archive to open")));
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     QString fileName;
     if (parser.positionalArguments().count()) {
         fileName = parser.positionalArguments().at(0);
     } else {
-        fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), i18n("Zip file (*.zip)"));
+        fileName = QFileDialog::getOpenFileName(nullptr, QString(), QString(), QStringLiteral("Zip file (*.zip)"));
     }
     if (fileName.isEmpty()) {
         return 0;
